function EmbedTex(savefile,infilenames,varargin)
% Program to embed .tex regression output in a tex file that will compile.
% 
% Required:
% infilename: name of .tex file(s) containing regression output
% using: name of output .tex file that will compile
% 
% Options:
% append: inserts the table at the bottom of an existing file of tables (this and only this part of the file relies on a command line instruction that may be system-dependent)
% replace: replaces existing embed file with a new file containing the single table
% title: title of latex file
% author: author of latex file
% landscape: make all pages landscape
% pdflscape: use pdflscape package instead of lscape package. The result is to rotate landscape pages on the screen.
% thousands: set group-separator to {,} to accomodate thousands.
% 
% This includes my standard latex options. Need to modify the file to add any others.
% 
% Written by Johannes Wieland; an adaption of Gabriel Chodorow-Reich's Stata program and provided without any warranty
% This version: January 2015

% separate file names into tokens for saving
filetokens  =   regexp(infilenames, ' ', 'split');
inputs  =   [];
for jj=1:length(filetokens)
	if isempty(regexp(filetokens{jj},'\/','Once'))==0
		inputs = [inputs '  \\input{' filetokens{jj} '} \n'];
    end
    if mod(jj,8)==0
        inputs = [inputs '  \\clearpage \n'];
    end
end

% separating varargin into fields and structures
if isempty(varargin)==0
    texpropind  =   0;
    for jj=1:length(varargin)
        if isstruct(varargin{jj})
            texprop     =   varargin{jj};
            varargin{jj}=   [];
            texpropind  =   1;
        end
    end
    varargin    =   cell2struct(varargin,varargin,2);
    if texpropind==0
        texprop     =   struct;
    end
else
    varargin    =   struct;
    texprop     =   struct;
end

if isfield(texprop,'author')==0
    texprop.author  =   [];
end
if isfield(texprop,'title')==0
    texprop.title   =   [];
end

% landscape option
if isfield(varargin,'landscape')
	input = ['\\begin{landscape}  \n ' inputs ' \\end{landscape} \n\n '];

else
	input = [ inputs ' \n'];
end

% append not currently an option
if isfield(varargin,'append')==1
    
    disp('Option not currently coded')
    return
end
	


if isfield(varargin,'thousands')
    group_digits='group-digits';
    group_separator='group-separator';
else 
    group_digits='group-digits';
    group_separator='group-separator';
end
fid = fopen([savefile '.tex'],'w');
fprintf(fid,'\\documentclass[12pt] {article}\n');
fprintf(fid,'\\usepackage{booktabs}\n');
fprintf(fid,'\\usepackage{fullpage}\n');
fprintf(fid,'\\usepackage{tabularx}\n');
fprintf(fid,'\\renewcommand{\\tabularxcolumn}[1]{>{\\centering\\arraybackslash}m{#1}}\n');
fprintf(fid,'\\newcolumntype{L}{>{\\centering}X}\n');
fprintf(fid,['\\usepackage{pdflscape}\n']);
fprintf(fid,'\\usepackage{longtable}\n');
fprintf(fid,'\\usepackage{dcolumn}\n');
fprintf(fid,'\\usepackage{amssymb}\n');
fprintf(fid,'\\usepackage{amsfonts}\n');
fprintf(fid,'\\usepackage{amsmath}\n');
fprintf(fid,'\\usepackage{graphicx}\n');
fprintf(fid,'\\usepackage[dvipsnames,table]{xcolor}\n');
fprintf(fid,'\\definecolor{light-gray}{gray}{0.90}\n');	
fprintf(fid,'\\usepackage{epsfig}\n');
fprintf(fid,'\\usepackage{epstopdf}\n');
fprintf(fid,'\\usepackage{hyperref}\n');
fprintf(fid,'\\usepackage{refstyle}\n');
fprintf(fid,'\\usepackage[noabbrev]{cleveref}\n');
fprintf(fid,'\\usepackage{siunitx}\n');
fprintf(fid,'\\sisetup{ detect-mode, \n');
fprintf(fid,'          group-digits            = false ,\n');
fprintf(fid,'          input-signs             = ,\n');
fprintf(fid,'          input-symbols           = ()[]-+* ,\n');
fprintf(fid,'          input-open-uncertainty  = ,\n');
fprintf(fid,'          input-close-uncertainty = ,\n');
fprintf(fid,'          table-align-text-post   = false,\n');
fprintf(fid,'          table-number-alignment  = center,\n');
fprintf(fid,['          ' group_digits '            = integer,\n']);
fprintf(fid,['          ' group_separator '         = {,}\n']);
fprintf(fid,'        }\n\n');

fprintf(fid,['\\title{' texprop.title '}\n']);
fprintf(fid,['\\author{' texprop.author '}\n']);
fprintf(fid,'\\topmargin=6pt\n');
fprintf(fid,'\\setlength{\\footskip}{15pt}\n');
fprintf(fid,'\\begin{document}\n');
fprintf(fid,'\\maketitle\n');

fprintf(fid,input);

fprintf(fid,'\\end{document}');

fclose(fid);

end