	clear all
	set more off
	#delimit;
	discard;
	version 13;

	/*************************************************************************************************************
	This do-file graphs and runs regressions to understand the cross-industry effect of the 40-hour law.
	*************************************************************************************************************/

	/*Change path below as needed. */
	cd "~/Dropbox/Spring33/Cohen-Setton_Hausman_Wieland_data_programs/Stata/Code/";
	do Paths;
	tempfile data;

	*local for assert checks;
	local tol = 0.001;


	/*************************************************************************************************************
	1. Load data from decree sheet
	*************************************************************************************************************/
	/*Importing decree dates*/
	import excel "$DataPath/decrees.xlsx", sheet(decrees) cellrange(A1:M76) firstrow clear;
	
	qui gen decree_month = mofd(Datedentreenvigueurdudecr);
	assert decree_month == tm(1936m11) if IndustrieOccupation  == "Mtallurgie";


	/* Expression below gives the fraction of the month elapsed when the 40 hour week restriction goes into effect. */
	qui gen decree_DayFrac = day(Datedentreenvigueurdudecr)/(dofm(decree_month+1)-dofm(decree_month));
	assert abs(decree_DayFrac - 28/30)< `tol' if IndustrieOccupation  == "Mtallurgie";
	
	*The line below changes decree_month to be the next month if the decree occured late in the month, so late that it wouldn't effect 
	*IP in that month;
	
	replace decree_month = decree_month + 1 if decree_DayFrac > .75; 

	qui format decree_month %tm;

	/*Generating matching string variables*/
	qui gen IPMatch1 = subinstr(subinstr(subinstr(substr(IPMain,1,24)," ","",.),"'","",.),"-","",.);
	qui gen IPMatch2 = subinstr(subinstr(subinstr(substr(IPsubindex1,1,24)," ","",.),"'","",.),"-","",.);
	qui replace IPMatch2 = subinstr(subinstr(subinstr(substr(IPsubindex2,1,24)," ","",.),"'","",.),"-","",.) if IPsubindex2!="";
	qui gen EmpMatch1 = subinstr(subinstr(subinstr(substr(Employment,1,24)," ","",.),"'","",.),"-","",.);
	qui gen EmpMatch2 = subinstr(subinstr(subinstr(substr(Employmentsubindex,1,24)," ","",.),"'","",.),"-","",.);
	qui save "$StDataPath/decrees", replace;

	/*Importing production data*/
	import excel "$DataPath/decrees.xlsx", sheet(production) cellrange(A1:AU156) firstrow clear;
	qui drop if _n==3;
	qui drop if _n==1;
	local subindustry;
	local curindustry;
	foreach var of varlist * {;
		local newname=`var'[1];
		local varlab: variable label `var';
		display "`newname'";
		if "`newname'"=="." | "`newname'"=="18" {;
			rename `var' IP`var';
			local curindustry "`curindustry' `var'";
			local subindustry "`subindustry' `var'";
		};
		else {;
			local newname=subinstr(subinstr(subinstr(substr("`newname'",1,24)," ","",.),"'","",.),"-","",.);
			local varlab=subinstr("`varlab'"," ","",.);
			qui rename `var' IP`newname';
			local curindustry "`curindustry' `varlab'";
			local subindustry "`subindustry' `newname'";
		};	
	};
	local curindustry = regexr("`curindustry'","Index ","");
	local subindustry = regexr("`subindustry'","Subindex ","");
	qui drop if _n==1;
	qui tostring *, replace;
	foreach var of varlist * {;	
		qui: replace `var'="." if `var'=="n.a." | `var'=="n.i.";
	};
	qui gen Date = monthly(IPSubindex,"M19Y");
	qui drop IPSubindex;
	qui format Date %tm;
	qui destring, replace;
	qui reshape long IP, i(Date) j(Industry) string;

	/*label aggregate industries*/
	gen Aggregate = "";
	tokenize "`subindustry'";
	forvalues jj=1/`:word count `subindustry'' {;
		qui: replace Aggregate = "`:word `jj' of `curindustry''" if Industry=="``jj''";
	
	};
	/*Generating matching string variables*/
	qui gen IPMatch1 = Aggregate;
	qui gen IPMatch2 = Industry if Industry!=Aggregate;

	*a few checks;
	assert IP == 118.5 if Industry == "Bauxite" & Date == tm(1936m10);
	assert IP == 68.0 if Industry == "Cuir" & Date == tm(1937m08);
	assert IP == 127.5 if Industry == "Papier" & Date == tm(1933m1);

	qui save "$StDataPath/production", replace;


	/*Importing hours data */;
	#delimit;
	import excel "$DataPath/work_time.xlsx", sheet(data) firstrow clear;

	drop overall;
	rename * hours*;
	rename hoursdate date;

	gen Date = mofd(date);
	format Date %tm;
	drop date;


	qui reshape long hours, i(Date) j(Industry) string;

	gen IPMatch1 = Industry;
	gen IPMatch2 = "";


	qui save "$StDataPath/hours", replace;

	/*************************************************************************************************************
	2. Merging dates with production and hours data

	*************************************************************************************************************/
	/*merge production with hours */
	qui use "$StDataPath/hours";
	merge 1:1 IPMatch1 Date IPMatch2 using "$StDataPath/production";
	qui save "$StDataPath/merged", replace;

	/*merge with decree dates*/
	clear all;
	tempfile data;
	qui use "$StDataPath/decrees";
	qui keep if IPMatch1!="" & IPMatch2!="?";
	qui keep IP* decree_month decree_DayFrac IndustrieOccupation;
	qui duplicates drop IP* decree_month decree_DayFrac , force;
	qui save `data';

	qui use "$StDataPath/merged", clear;
	merge m:1 IPMatch1 IPMatch2 using `data', keepusing(decree_month decree_DayFrac IndustrieOccupation) nogenerate;
	qui drop if Date==.;
	qui save "$StDataPath/merged", replace;




	/*************************************************************************************************************
	3. Creating variables
	*************************************************************************************************************/

	#delimit;
	qui use "$StDataPath/merged", clear;

	/*Decree variable*/
	qui sort Aggregate Industry Date;
	qui gen decree_on = (Date>=decree_month) if decree_month<.;
	qui replace decree_on = 0 if Date>=ym(1938,11) & decree_on==1;
	label variable decree_on "40-hour restriction";

	/*Devaluation dummy*/
	qui gen devaluation = (Date>=ym(1936,10));
	label variable devaluation "Devaluation";

	/*industry group variables*/
	qui egen ind_code = group(Industry);
	qui egen date_code = group(Date);
	qui xtset ind_code Date;

	/*log of variables*/
	foreach var of varlist IP hours  {;
		qui gen l`var' = ln(`var');
	};


	/*monthly dummies*/
	gen month_dum = month(dofm(Date));
	gen august = (month(dofm(Date))==8);
	gen post1936 = (year(dofm(Date))>=1936);
	gen ind_code_month_dum = ind_code*100+month_dum;

	/*measuring decline during depression*/
	forvalues jj=29(1)36 {;
		qui egen lIP`jj' = max(lIP * (Date==ym(19`jj',1)) ), by(ind_code);
	};
	foreach kk in 29 33 {;
		forvalues jj=29(1)36 {;
			qui gen decline`kk'`jj' = lIP`jj' - lIP`kk' if lIP`kk'!=0 & lIP`jj'!=0;
			label variable decline`kk'`jj' "Decline 19`kk'-19`jj'";
		};
	};


	qui save "$StDataPath/merged", replace;

	*do some checks here;
	#delimit;
	assert IP == 118.5 if Industry == "Bauxite" & Date == tm(1936m10);
	assert IP == 68.0 if Industry == "Cuir" & Date == tm(1937m08);
	assert IP == 127.5 if Industry == "Papier" & Date == tm(1933m1);
	assert IP == 81.3 if Industry=="Houille" & Date==tm(1936m6);
	assert IP == 85.6 if Industry=="Petrole" & Date==tm(1937m1);
	assert IP == 96.3 if Industry=="Coton" & Date==tm(1928m1);
	assert IP == 47.2 if Industry=="Chanvre" & Date==tm(1934m12);
	assert IP == 79.3 if Industry=="Metallurgie" & Date==tm(1938m2);
	assert IP == 98.8 if Industry=="ConstructionsAutomobile" & Date==tm(1936m12);
	assert IP == 199 if Industry=="Rayonne" & Date==tm(1937m1);
	assert IP == 98 if Industry=="Textiles" & Date==tm(1939m7);

	assert decree_on ==0 if Industry == "Metallurgie" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "Metallurgie" & Date == tm(1936m12);

	assert decree_on ==0 if Industry == "Cuir" & Date == tm(1937m2);
	assert decree_on ==1 if Industry == "Cuir" & Date == tm(1937m3);
	assert decree_on ==0 if Industry == "Cuir" & Date == tm(1938m12);

	assert decree_on ==0 if Industry == "ConstructionsAutomobile" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "ConstructionsAutomobile" & Date == tm(1936m12);

	assert decree_on ==0 if Industry == "Zinc" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "Zinc" & Date == tm(1936m12);
	assert decree_on ==0 if Industry == "Zinc" & Date == tm(1938m12);

	assert decree_on ==0 if Industry == "Rayonne" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "Rayonne" & Date == tm(1937m2);
	assert decree_on ==0 if Industry == "Rayonne" & Date == tm(1938m12);

	assert decree_on ==0 if Industry == "Petrole" & Date == tm(1937m5);
	assert decree_on ==1 if Industry == "Petrole" & Date == tm(1937m6);
	


/*************************************************************************************************************
4. Seasonal adjustment. Note: The code below uses 'arima', which is slow. 
*************************************************************************************************************/



/*Industrial production*/
qui levelsof ind_code if lIP<. & decree_on<., local(IPids);
qui gen lIP_sa = lIP;
qui gen lhours_sa = lhours;

foreach id in `IPids' {;
	display "`id'";
	foreach var of varlist lIP {;
		qui xi, noomit prefix(_) i.month_dum;
		qui arima `var' _month_dum_* if ind_code==`id', ar(1) ma(1) noconstant;
		
		/*Subtract month/quarter dummy from SA variable*/
		local unitmean = 0;
		forvalues mm = 1/12 {;
			qui replace `var'_sa = `var'_sa  - _b[_month_dum_`mm'] if month_dum==`mm' &  ind_code==`id'; 
			local unitmean = `unitmean' + _b[_month_dum_`mm'];
		}; 
		local unitmean = `unitmean'/12;  
		/*Add back mean of month/quarter dummies to SA variable*/
		qui replace `var'_sa = `var'_sa + `unitmean' if ind_code==`id'; 
	};
};

gen IP_sa = exp(lIP_sa);

qui save "$StDataPath/merged_sa", replace;



/*************************************************************************************************************
5. Hours and production graphs
*************************************************************************************************************/

#delimit;
qui use "$StDataPath/merged", clear;


*translations for graphs;
capture gen ename = "";
capture replace ename = "leather" if Industry=="Cuir"; 
replace ename = "construction" if Industry=="Batiment"; 
replace ename = "metallurgy" if Industry=="Metallurgie"; 
replace ename = "chemical products" if Industry=="ProduitsChimiques";
replace ename = "textiles" if Industry=="Textiles";
replace ename = "metal working" if Industry=="TravailDesMetaux";

save "$StDataPath/merged", replace;


*check some data points;
assert hours == 46.8 if Industry == "Textiles" & Date == tm(1931m1);
assert hours == 39.8 if Industry == "Cuir" & Date == tm(1937m4);
assert hours == 46.4 if Industry == "TravailDesMetaux" & Date == tm(1936m12);


qui levelsof ind_code if hours<. & decree_on<., local(IPids_hours);
foreach id in `IPids_hours' {;
	 
	 disp "`id'";
	 keep if ind_code==`id';
	 local decree=decree_month;
	 local ename_l = ename;
	 disp `decree';
	 disp Industry[1];
	 su hours if ind_code==`id' & tin(1936m1,1937m12);
     tsline hours if ind_code==`id' & tin(1936m1,1937m12), tline(`decree') legend(off) ytitle("Weekly hours, `ename_l'") /// 
     xtitle("Date") ylabel(,nogrid) graphregion(color(white)) || pcarrowi `=r(max)+2' `=`decree'+2' `=r(max)+1' `decree' (3) "40-hour law";
	 graph export "$StOutPath/`ename_l'_hours.pdf", replace;
	 graph export "$StOutPath/`ename_l'_hours.eps", replace;
	 drop _all;
	 qui use "$StDataPath/merged";
};


#delimit;
set more off;
clear all;
qui use "$StDataPath/merged_sa", clear;
keep if decree_on<.;
qui xtset ind_code Date;



*Graphs showing the time series of production in each industry with a vertical line
*for the 40-hour week law application;

*translations for graphs;
capture drop ename;
capture	gen ename="Mining" if Industry=="Mines";
replace ename="Coal" if Industry=="Houille";
replace ename="Metal mining"  if Industry=="MineraiDeFer";
replace ename="Potash"   if Industry=="Potasse";
replace ename="Oil"  if Industry=="Petrole";
replace ename="Bauxite"  if Industry=="Bauxite";
replace ename="Salt"  if Industry=="Sel";
replace ename="Chemical products"  if Industry=="ProduitsChimiques";
replace ename="Paper" if Industry=="Papier";
replace ename="Textiles"  if Industry=="Textiles";
replace ename="Cotton"  if Industry=="Coton";
replace ename="Wool"  if Industry=="Laine";
replace ename="Silk"  if Industry=="Soie";
replace ename="Rayon"  if Industry=="Rayonne";
replace ename="Linen" if Industry=="Lin";
replace ename="Hemp" if Industry=="Chanvre";
replace ename="Leather" if Industry=="Cuir";
replace ename="Metallurgy" if Industry=="Metallurgie";
replace ename="Cast iron production" if Industry=="Fonte";
replace ename="Steel production" if Industry=="Acier";
replace ename="Zinc production" if Industry=="Zinc";
replace ename="Metal working" if Industry=="TravailDesMetaux";
replace ename="Steel working" if Industry=="Consomationdacier";
replace ename="Copper working" if Industry=="ConsomationdeCuivre";
replace ename="Shipbuilding" if Industry=="ConstructionsNavales";
replace ename="Auto production" if Industry=="ConstructionsAutomobile";
replace ename="Construction" if Industry=="Batiment";
replace ename="Gas and electricity" if Industry=="Gazelectricite";
replace ename="Natural gas" if Industry=="Gaz";
replace ename="Electricity" if Industry=="Electricite";



save "$StDataPath/merged_sa", replace;

qui levelsof ind_code if lIP<. & decree_on<., local(IPids);
foreach id in `IPids' {;
	 
	 keep if ind_code==`id';
	 format decree_month %tm;
	 local decree=decree_month;
	 local ename_l = ename;
	 disp `decree';
	 disp Industry[1];
	 qui su IP_sa if ind_code==`id' & tin(1936m1,1937m12);
     tsline IP_sa if ind_code==`id' & tin(1936m1,1937m12), tline(`decree') legend(off) ytitle("`ename_l' (s.a.)") /// 
     xtitle("Date") ylabel(,nogrid) graphregion(color(white)) || pcarrowi `=r(max)+10/r(sd)' `=`decree'+2' `=r(max)+1' `decree' (3) "40-hour law";
	 graph export "$StOutPath/`ename_l'.pdf", replace;
	 graph export "$StOutPath/`ename_l'.eps", replace;
	 drop _all;
	 qui use "$StDataPath/merged_sa";
};




*drop industries not used in the baseline regressions;
drop if Industry=="Mines";
drop if Industry=="Textiles";
drop if Industry=="Metallurgie";
drop if Industry=="TravailDesMetaux";
drop if Industry=="ConstructionsNavales";
drop if Industry=="Gaz";
drop if Industry=="Gazelectricite";
drop if Industry=="Siderurgie";
drop if Industry=="Glacesetvitres";
drop if Industry=="Electricite";
save "$StDataPath/merged_sa2", replace;


/*************************************************************************************************************
6. Event study graph
*************************************************************************************************************/

#delimit;
use "$StDataPath/merged_sa2", clear; 

local sauvy_exclude `" Industry!=`"Batiment"' & Industry!=`"Cuir"' & Industry!=`"Consomationdacier"' & Industry!=`"ConsomationdeCuivre"'"';


/* Make event study graph */
*add 12 leads / lags of decree;
newey D.lIP_sa L(-12/12).D.decree_on i.date_code i.ind_code, lag(12) force;

matrix b = e(b)';
matrix V = vecdiag(e(V))';

matrix event_results = b,V;

svmat event_results, names(coef_var);

replace coef_var1 = coef_var1*100;
replace coef_var2 = sqrt(coef_var2)*100;

rename coef_var1 coefficient;
rename coef_var2 stan_error;

gen month = _n - 13;


serrbar coefficient stan_error month if abs(month)<13, scale(2) ///
ylabel(, nogrid) legend(off) ytitle("Coefficient on change in 40-hour law (percentage points)") xtitle(Months before / after law takes effect) xlabel(-12(2)12) ///
  graphregion(color(white)) yline(0, lcolor(black)) clcolor(blue red red) ///
  clpattern(l "-" "-") title("Coefficient and 2 se bands"); 
graph export "$StOutPath/figure9.pdf", replace;
graph export "$StOutPath/figure9.eps", replace;


/*************************************************************************************************************
7. Baseline and excluding industries with measurement error regressions
*************************************************************************************************************/

#delimit;
use "$StDataPath/merged_sa2", clear;

foreach control in  `"if `sauvy_exclude' "'  ""  {;
	
	local mlabelset;
	

	foreach fecontr in "i.date_code i.ind_code" "L(1/12).D.lIP_sa i.date_code i.ind_code" "L(0/12).D.devaluation  i.ind_code" "L(1/12).D.lIP_sa  L(0/12).D.devaluation  i.ind_code" {;
		
		foreach var of varlist lIP_sa  {;
			
			foreach dlag in  0 12 {;
			
				newey D.`var' L(0/`dlag').D.decree_on `fecontr' `control', lag(12) force;
				di "line 308";
				eststo;
				
				di "line 309";
				if regexm(`"`fecontr'"',`"lIP_sa"') == 1 {;
					qui estadd local laglen "\multicolumn{1}{c}{12}";
				};
				else {;
					qui estadd local laglen "\multicolumn{1}{c}{0}";
				};
				
				/* calculating cumulative effect on IP*/;
				if `"`dlag'"'!=`"0"' {;
					
					qui estadd local laglen_d "\multicolumn{1}{c}{`dlag'}";
					
					di "line 322";
					local dy0 = _b[D.decree_on];
					local y	=	`dy0';	//impact;
						
					forvalues jj=1(1)`dlag' {;	
						local dy`jj' = _b[L`jj'D.decree_on]; //lagged effect;
						if regexm(`"`fecontr'"',`"lIP_sa"') == 1 {;
							forvalues zz=1(1)`jj' {;
								local pp = `jj'-`zz';
								local dy`jj' = `dy`jj''+_b[L`zz'D.lIP_sa]*`dy`pp''; //change in IP in period jj including dynamic lagged effect;
							}; 
						};
						local y = `y'+`dy`jj'';

					};
					local y = round(`y',0.001);
					di "`y'";
					qui estadd local cum "\multicolumn{1}{c}{`y'}";
					
					local mlabelset = `"`mlabelset'"' + " " + `"""' + "Cumulative" + `"""';
					
					/* impulse response function */
					#delimit;
					matrix coeff = e(b);
					matrix varcoeff = e(V);
					local p=0;
					local h=12;
					local psave;
					local tsave;
					if regexm(`"`fecontr'"',`"lIP_sa"') == 1 {;
						local p=12;
						local psave "_ylags";
						di "with lags";
					};
					if regexm(`"`fecontr'"',`"date_code"')==1 {;
						local tsave "_tfe";
					};
					mata: irf1 = irf_single("coeff", "varcoeff", `p', `dlag', 13, 1000, 1);
					matrix IRF = r(IRF)';
					disp "IRF coeff";
					matrix list IRF;
					matrix CI1 = r(IRFCIL)';
					matrix CI2 = r(IRFCIU)';
					matrix irflenm = [0,1,2,3,4,5,6,7,8,9,10,11,12];
					coefplot matrix(IRF), ci((CI1 CI2)) recast(line) ciopts(recast(rline) lpattern(dash) color(red)) at(matrix(irflenm)) xlabel(0(3)12) ///
					title("Effect of 40-hour law on Industrial Production") ytitle("log points") xtitle(Months) graphregion(color(white)) plotregion(style(none) margin(zero)) yline(0, lcolor(black) lpattern(shortdash));
					local filename `"irf_lag`dlag'`psave'`tsave'"';
					qui graph export `"$StOutPath/`filename'.pdf"', replace;
					qui graph export `"$StOutPath/`filename'.eps"', replace;
					
						
				};
				else {;
					qui estadd local laglen_d "\multicolumn{1}{c}{0}";
					qui estadd local cum "\multicolumn{1}{c}{-}";
					local mlabelset = `"`mlabelset'"' + " " + `"""' + "Baseline" + `"""';
				};
				
				qui estadd local obs "\multicolumn{1}{c}{`e(N)'}";
				
			};
		};
	};
	
	
	if regexm(`"`control'"',`"if"') == 1 {;
		local table_title "measurement_error";
	};
	else {;
		local table_title "table2A";
	};
	
	esttab using "$StOutPath/`table_title'.tex", coeflabels(D.decree_on "$\Delta$ 40-hour restriction" D.devaluation "$\Delta$ Devaluation") ///
	b(3) se(3) noobs label title(Impact of 40-hour law) ///
	legend starlevels( \sym{+} 0.10 \sym{*} 0.05 \sym{**} 0.010) ///
	compress fragment   ///
	keep(D.decree_on D.devaluation) ///
	mgroups("Ind-FE + time-FE" "Ind-FE + time-FE + lags"  "Ind-FE" "Ind-FE + lags", pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	mlabels(`mlabelset', prefix("\multicolumn{1}{c}{") suffix("}") ) ///
	indicate("\hline Time-FE = *date_code" "Industry-FE = *ind_code", labels("\multicolumn{1}{c}{Yes}" "\multicolumn{1}{c}{No}")) ///
	scalars("cum 12-mth cumulative effect" "laglen_d Decree lags" "laglen Dep. var. lags" "obs \hline N") ///
	 nonum ///
	substitute(< \textless [1em] "") replace 
	;
	
	eststo clear;
};


/*************************************************************************************************************
8. Industry Group level regression
*************************************************************************************************************/


/*make table using only the set of industries at the level at which the 40-hour law varied. */

set more off;
use "$StDataPath/merged_sa", clear;

drop if Industry=="Coton";
drop if Industry=="Laine";
drop if Industry=="Rayonne";
drop if Industry=="Lin";
drop if Industry=="Chanvre";
drop if Industry=="Fonte";
drop if Industry=="Acier";
drop if Industry=="Zinc";
drop if Industry=="Consomationdacier";
drop if Industry=="ConsomationdeCuivre";
drop if Industry=="ConstructionsAutomobile";
drop if Industry=="Soie";

drop if Industry=="Mines";
drop if Industry=="ConstructionsNavales";
drop if Industry=="Gaz";
drop if Industry=="Gazelectricite";
drop if Industry=="Siderurgie";
drop if Industry=="Glacesetvitres";
drop if Industry=="Electricite";

*verify that this leaves 13 industries;
by Industry, sort: gen nvals_industry = _n == 1; 
count if nvals_industry;
assert r(N)==13; 

sort ind_code Date;


local mlabelset;
	

	foreach fecontr in "i.date_code i.ind_code" "i.date_code i.ind_code L(1/12).D.lIP_sa" "dL(0/12).devaluation  i.ind_code" "L(1/12).D.lIP_sa  dL(0/12).devaluation  i.ind_code" {;
		
		foreach var of varlist lIP_sa  {;
			
			foreach dlag in  0 12 {;
			
			
				newey D.`var' DL(0/`dlag').decree_on `fecontr', lag(12) force;
				di "line 308";
				eststo;
				
				di "line 309";
				if regexm(`"`fecontr'"',`"lIP_sa"') == 1 {;
					qui estadd local laglen "\multicolumn{1}{c}{12}";
				};
				else {;
					qui estadd local laglen "\multicolumn{1}{c}{0}";
				};
				
				/* calculating cumulative effect on IP*/;
				if `"`dlag'"'!=`"0"' {;
					
					qui estadd local laglen_d "\multicolumn{1}{c}{`dlag'}";
					
					di "line 322";
					local dy0 = _b[D.decree_on];
					local y	=	`dy0';	//impact;
						
					forvalues jj=1(1)`dlag' {;	
						local dy`jj' = _b[L`jj'D.decree_on]; //lagged effect;
						if regexm(`"`fecontr'"',`"lIP_sa"') == 1 {;
							forvalues zz=1(1)`jj' {;
								local pp = `jj'-`zz';
								local dy`jj' = `dy`jj''+_b[L`zz'D.lIP_sa]*`dy`pp''; //change in IP in period jj including dynamic lagged effect;
							}; 
						};
						local y = `y'+`dy`jj'';

					};
					local y = round(`y',0.001);
					di "Cumulative effect `y'";
					qui estadd local cum "\multicolumn{1}{c}{`y'}";
					
					local mlabelset = `"`mlabelset'"' + " " + `"""' + "Cumulative" + `"""';
						
				};
				else {;
					qui estadd local laglen_d "\multicolumn{1}{c}{0}";
					qui estadd local cum "\multicolumn{1}{c}{-}";
					local mlabelset = `"`mlabelset'"' + " " + `"""' + "Baseline" + `"""';
				};
				
				qui estadd local obs "\multicolumn{1}{c}{`e(N)'}";
				
			};
		};
	};
	
	
	
	local table_title "table2B";
		
	esttab using "$StOutPath/`table_title'.tex", coeflabels(D.decree_on "$\Delta$ 40-hour restriction" D.devaluation "$\Delta$ devaluation") ///
	b(3) se(3) noobs label title(Impact of 40-hour law) ///
	legend starlevels( \sym{+} 0.10 \sym{*} 0.05 \sym{**} 0.010) ///
	compress fragment   ///
	keep(D.decree_on D.devaluation) ///
	mgroups("Ind-FE + time-FE" "Ind-FE + time-FE + lags"  "Ind-FE" "Ind-FE + lags", pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	mlabels(`mlabelset', prefix("\multicolumn{1}{c}{") suffix("}") ) ///
	indicate("\hline Time-FE = *date_code" "Industry-FE = *ind_code", labels("\multicolumn{1}{c}{Yes}" "\multicolumn{1}{c}{No}")) ///
	scalars("cum 12-mth cumulative effect" "laglen_d Decree lags" "laglen Dep. var. lags" "obs \hline N") ///
	 nonum ///
	substitute(< \textless [1em] "") replace 
	;
	eststo clear;



