	clear all
	set more off
	#delimit;
	discard;
	version 13;

	/*************************************************************************************************************
	This do-file makes graphs / regressions to examine the effect of the 40-hour law on prices.
	It is analagous to what is done in decrees.do for production. (Except that fewer series are available for prices.)
	*************************************************************************************************************/

	/*Generate paths. Change path below if using on a different computer. */
	cd "~/Dropbox/Spring33/Cohen-Setton_Hausman_Wieland_data_programs/Stata/Code/";
	do Paths;
	tempfile data;

	*local for assert checks;
	local tol = 0.001;


	/*************************************************************************************************************
	1. Load data from decree sheet
	*************************************************************************************************************/

	/*Importing decree dates*/
	import excel "$DataPath/decrees.xlsx", sheet(decrees) cellrange(A1:M76) firstrow clear;
	qui gen decree_month = mofd(Datedentreenvigueurdudecr);
	assert decree_month == tm(1936m11) if IndustrieOccupation  == "Mtallurgie";


	/* Expression below gives the fraction of the month elapsed when the 40 hour week restriction goes into effect. */
	qui gen decree_DayFrac = day(Datedentreenvigueurdudecr)/(dofm(decree_month+1)-dofm(decree_month));
	assert abs(decree_DayFrac - 28/30)< `tol' if IndustrieOccupation  == "Mtallurgie";
	
	*The line below changes decree_month to be the next month if the decree occured late in the month, so late that it wouldn't effect 
	*that month;
	
	replace decree_month = decree_month + 1 if decree_DayFrac > .75; 
	

	qui format decree_month %tm;

	/*Generating matching string variables*/
	qui gen IPMatch1 = subinstr(subinstr(subinstr(substr(IPMain,1,24)," ","",.),"'","",.),"-","",.);
	qui gen IPMatch2 = subinstr(subinstr(subinstr(substr(IPsubindex1,1,24)," ","",.),"'","",.),"-","",.);
	qui replace IPMatch2 = subinstr(subinstr(subinstr(substr(IPsubindex2,1,24)," ","",.),"'","",.),"-","",.) if IPsubindex2!="";
	qui gen EmpMatch1 = subinstr(subinstr(subinstr(substr(Employment,1,24)," ","",.),"'","",.),"-","",.);
	qui gen EmpMatch2 = subinstr(subinstr(subinstr(substr(Employmentsubindex,1,24)," ","",.),"'","",.),"-","",.);
	qui save "$StDataPath/decrees", replace;

	/*Importing production data*/
	import excel "$DataPath/decrees.xlsx", sheet(production) cellrange(A1:AU156) firstrow clear;
	qui drop if _n==3;
	qui drop if _n==1;
	local subindustry;
	local curindustry;
	foreach var of varlist * {;
		local newname=`var'[1];
		local varlab: variable label `var';
		display "`newname'";
		if "`newname'"=="." | "`newname'"=="18" {;
			rename `var' IP`var';
			local curindustry "`curindustry' `var'";
			local subindustry "`subindustry' `var'";
		};
		else {;
			local newname=subinstr(subinstr(subinstr(substr("`newname'",1,24)," ","",.),"'","",.),"-","",.);
			local varlab=subinstr("`varlab'"," ","",.);
			qui rename `var' IP`newname';
			local curindustry "`curindustry' `varlab'";
			local subindustry "`subindustry' `newname'";
		};	
	};
	local curindustry = regexr("`curindustry'","Index ","");
	local subindustry = regexr("`subindustry'","Subindex ","");
	qui drop if _n==1;
	qui tostring *, replace;
	foreach var of varlist * {;	
		qui: replace `var'="." if `var'=="n.a." | `var'=="n.i.";
	};
	qui gen Date = monthly(IPSubindex,"M19Y");
	qui drop IPSubindex;
	qui format Date %tm;
	qui destring, replace;
	qui reshape long IP, i(Date) j(Industry) string;

	/*label aggregate industries*/
	gen Aggregate = "";
	tokenize "`subindustry'";
	forvalues jj=1/`:word count `subindustry'' {;
		qui: replace Aggregate = "`:word `jj' of `curindustry''" if Industry=="``jj''";
	
	};
	/*Generating matching string variables*/
	qui gen IPMatch1 = Aggregate;
	qui gen IPMatch2 = Industry if Industry!=Aggregate;

	*a few checks;
	assert IP == 118.5 if Industry == "Bauxite" & Date == tm(1936m10);
	assert IP == 68.0 if Industry == "Cuir" & Date == tm(1937m08);
	assert IP == 127.5 if Industry == "Papier" & Date == tm(1933m1);

	qui save "$StDataPath/production", replace;


	/*Importing hours data */;
	#delimit;
	import excel using "$DataPath/work_time.xlsx", sheet(data) firstrow clear;

	drop overall;
	rename * hours*;
	rename hoursdate date;

	gen Date = mofd(date);
	format Date %tm;
	drop date;


	qui reshape long hours, i(Date) j(Industry) string;

	gen IPMatch1 = Industry;
	gen IPMatch2 = "";


	qui save "$StDataPath/hours", replace;



	/*Importing price data */;
	#delimit;
	import excel using "$DataPath/decrees.xlsx", sheet(prices) cellrange(A1:P118) firstrow clear;
	
	rename * price*;
	rename pricedate date;

	gen Date = mofd(date);
	format Date %tm;
	drop date;


	qui reshape long price, i(Date) j(Industry) string;

	gen IPMatch1 = Industry;
	gen IPMatch2 = "";


	qui save "$StDataPath/prices", replace;
	
	


	/*************************************************************************************************************
	2. Merging dates with production, hours, and price data

	*************************************************************************************************************/
	/*merge production with hours */
	qui use "$StDataPath/hours";
	merge 1:1 IPMatch1 Date IPMatch2 using "$StDataPath/production";
	drop _merge;
	qui save "$StDataPath/merged_prices", replace;

	/*merge with prices */
	merge 1:1 Industry Date using "$StDataPath/prices";
	qui save  "$StDataPath/merged_prices", replace;
	
	
	/*merge with decree dates*/
	clear all;
	tempfile data;
	qui use "$StDataPath/decrees";
	qui keep if IPMatch1!="" & IPMatch2!="?";
	qui keep IP* decree_month decree_DayFrac IndustrieOccupation;
	qui duplicates drop IP* decree_month decree_DayFrac , force;
	qui save `data';

	qui use "$StDataPath/merged_prices", clear;
	merge m:1 IPMatch1 IPMatch2 using `data', keepusing(decree_month decree_DayFrac IndustrieOccupation) nogenerate;
	qui drop if Date==.;
	qui save "$StDataPath/merged_prices", replace;


	
	

	/*************************************************************************************************************
	3. Creating variables
	*************************************************************************************************************/

	#delimit;
	qui use "$StDataPath/merged_prices", clear;

	/*Decree variable*/
	qui sort Aggregate Industry Date;
	qui gen decree_on = (Date>=decree_month) if decree_month<.;
	qui replace decree_on = 0 if Date>=ym(1938,11) & decree_on==1;
	label variable decree_on "40-hour restriction";

	/*Devaluation dummy*/
	qui gen devaluation = (Date>=ym(1936,10));
	label variable devaluation "Devaluation";

	/*industry group variables*/
	qui egen ind_code = group(Industry);
	qui egen date_code = group(Date);
	qui xtset ind_code Date;

	/*log of variables*/
	foreach var of varlist IP hours price {;
		qui gen l`var' = ln(`var');
	};


	/*monthly dummies*/
	gen month_dum = month(dofm(Date));
	gen august = (month(dofm(Date))==8);
	gen post1936 = (year(dofm(Date))>=1936);
	gen ind_code_month_dum = ind_code*100+month_dum;

	/*measuring decline during depression*/
	forvalues jj=29(1)36 {;
		qui egen lIP`jj' = max(lIP * (Date==ym(19`jj',1)) ), by(ind_code);
	};
	foreach kk in 29 33 {;
		forvalues jj=29(1)36 {;
			qui gen decline`kk'`jj' = lIP`jj' - lIP`kk' if lIP`kk'!=0 & lIP`jj'!=0;
			label variable decline`kk'`jj' "Decline 19`kk'-19`jj'";
		};
	};


	qui save "$StDataPath/merged_prices", replace;

	*do some checks here;
	#delimit;
	assert IP == 118.5 if Industry == "Bauxite" & Date == tm(1936m10);
	assert IP == 68.0 if Industry == "Cuir" & Date == tm(1937m08);
	assert IP == 127.5 if Industry == "Papier" & Date == tm(1933m1);
	assert IP == 81.3 if Industry=="Houille" & Date==tm(1936m6);
	assert IP == 85.6 if Industry=="Petrole" & Date==tm(1937m1);
	assert IP == 96.3 if Industry=="Coton" & Date==tm(1928m1);
	assert IP == 47.2 if Industry=="Chanvre" & Date==tm(1934m12);
	assert IP == 79.3 if Industry=="Metallurgie" & Date==tm(1938m2);
	assert IP == 98.8 if Industry=="ConstructionsAutomobile" & Date==tm(1936m12);
	assert IP == 199 if Industry=="Rayonne" & Date==tm(1937m1);
	assert IP == 98 if Industry=="Textiles" & Date==tm(1939m7);
	
	assert price == 352 if Industry=="Textiles" & Date==tm(1931m12);
	assert price == 403 if Industry=="Cuir" & Date==tm(1937m1);
	assert price == 222.5 if Industry=="Fonte" & Date==tm(1933m8);
	assert price == 893 if Industry=="Houille" & Date==tm(1939m1);
	assert price == 1.75 if Industry=="Electricite" & Date==tm(1934m4);
	
	
	

	assert decree_on ==0 if Industry == "Metallurgie" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "Metallurgie" & Date == tm(1936m12);

	assert decree_on ==0 if Industry == "Cuir" & Date == tm(1937m2);
	assert decree_on ==1 if Industry == "Cuir" & Date == tm(1937m3);
	assert decree_on ==0 if Industry == "Cuir" & Date == tm(1938m12);

	assert decree_on ==0 if Industry == "ConstructionsAutomobile" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "ConstructionsAutomobile" & Date == tm(1936m12);

	assert decree_on ==0 if Industry == "Zinc" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "Zinc" & Date == tm(1936m12);
	assert decree_on ==0 if Industry == "Zinc" & Date == tm(1938m12);

	assert decree_on ==0 if Industry == "Rayonne" & Date == tm(1936m10);
	assert decree_on ==1 if Industry == "Rayonne" & Date == tm(1937m2);
	assert decree_on ==0 if Industry == "Rayonne" & Date == tm(1938m12);

	assert decree_on ==0 if Industry == "Petrole" & Date == tm(1937m5);
	assert decree_on ==1 if Industry == "Petrole" & Date == tm(1937m6);
	


/*************************************************************************************************************
4. Seasonal adjustment of price data. Note: The code below uses 'arima', which is slow. 
*************************************************************************************************************/



* prices;
qui gen lprice_sa = lprice;
qui levelsof ind_code if lprice <. & decree_on<., local(IPids_prices);


foreach id in `IPids_prices' {;
	display "`id'";
	foreach var of varlist lprice {;
		qui xi, noomit prefix(_) i.month_dum;
		qui arima `var' _month_dum_* if ind_code==`id', ar(1) ma(1) noconstant;
		
		/*Subtract month/quarter dummy from SA variable*/
		local unitmean = 0;
		forvalues mm = 1/12 {;
			qui replace `var'_sa = `var'_sa  - _b[_month_dum_`mm'] if month_dum==`mm' &  ind_code==`id'; 
			local unitmean = `unitmean' + _b[_month_dum_`mm'];
		}; 
		local unitmean = `unitmean'/12;  
		/*Add back mean of month/quarter dummies to SA variable*/
		qui replace `var'_sa = `var'_sa + `unitmean' if ind_code==`id'; 
	};
};


qui save "$StDataPath/merged_sa_prices", replace;
qui save "$StDataPath/merged_sa_prices_backup", replace;




/*************************************************************************************************************
4. Graphs and regressions
*************************************************************************************************************/


#delimit;
set more off;
clear all;
qui use "$StDataPath/merged_sa_prices", clear;
replace decree_on = 0 if Date ==tm(1939m8);
keep if decree_on<.;
qui xtset ind_code Date;



replace devaluation = 0 if Date==tm(1936m9);
capture gen price_sa = exp(lprice_sa);
save "$StDataPath/merged_sa_prices", replace;



*drop industries not used in the baseline regressions; 
drop if Industry=="Textiles";
drop if Industry=="Gaz";
drop if Industry=="Electricite";



/*Regression in changes*/;
	
	local mlabelset;
	


	foreach fecontr in "i.date_code i.ind_code" "i.date_code i.ind_code L(1/12).D.lprice_sa" "L(0/12).D.devaluation  i.ind_code" "L(1/12).D.lprice_sa  L(0/12).D.devaluation  i.ind_code" {;
		
		foreach var of varlist lprice_sa  {;
			
			foreach dlag in  0 12 {;
							
				newey D.`var' L(0/`dlag').D.decree_on `fecontr' `control', lag(12) force;
				di "line 308";
				eststo;
				
				di "line 309";
				if regexm(`"`fecontr'"',`"lprice_sa"') == 1 {;
					qui estadd local laglen "\multicolumn{1}{c}{12}";
				};
				else {;
					qui estadd local laglen "\multicolumn{1}{c}{0}";
				};
				
				/* calculating cumulative effect on IP*/;
				if `"`dlag'"'!=`"0"' {;
					
					qui estadd local laglen_d "\multicolumn{1}{c}{`dlag'}";
					
					di "line 322";
					local dy0 = _b[D.decree_on];
					local y	=	`dy0';	//impact;
						
					forvalues jj=1(1)`dlag' {;	
						local dy`jj' = _b[L`jj'D.decree_on]; //lagged effect;
						if regexm(`"`fecontr'"',`"lprice_sa"') == 1 {;
							forvalues zz=1(1)`jj' {;
								local pp = `jj'-`zz';
								local dy`jj' = `dy`jj''+_b[L`zz'D.lprice_sa]*`dy`pp''; //change in IP in period jj including dynamic lagged effect;
							}; 
						};
						local y = `y'+`dy`jj'';

					};
					local y = round(`y',0.001);
					di "`y'";
					qui estadd local cum "\multicolumn{1}{c}{`y'}";
					
					local mlabelset = `"`mlabelset'"' + " " + `"""' + "Cumulative" + `"""';
						
				};
				else {;
					qui estadd local laglen_d "\multicolumn{1}{c}{0}";
					qui estadd local cum "\multicolumn{1}{c}{-}";
					local mlabelset = `"`mlabelset'"' + " " + `"""' + "Baseline" + `"""';
				};
				
				qui estadd local obs "\multicolumn{1}{c}{`e(N)'}";
				
			};
		};
	};
	
	
	
	local table_title "table3";
	
	esttab using "$StOutPath/`table_title'.tex", coeflabels(D.decree_on "$\Delta$ 40-hour restriction" D.devaluation "$\Delta$ Devaluation") ///
	b(3) se(3) noobs label title(Impact of 40-hour law) ///
	legend starlevels( \sym{+} 0.10 \sym{*} 0.05 \sym{**} 0.010) ///
	compress fragment   ///
	keep(D.decree_on D.devaluation) ///
	mgroups("Ind-FE + time-FE" "Ind-FE + time-FE + lags"  "Ind-FE" "Ind-FE + lags", pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	mlabels(`mlabelset', prefix("\multicolumn{1}{c}{") suffix("}") ) ///
	indicate("\hline Time-FE = *date_code" "Industry-FE = *ind_code", labels("\multicolumn{1}{c}{Yes}" "\multicolumn{1}{c}{No}")) ///
	scalars("cum 12-mth cumulative effect" "laglen_d Decree lags" "laglen Dep. var. lags" "obs \hline N") ///
	 nonum ///
	substitute(< \textless [1em] "") replace 
	;
	
	eststo clear;




